var a = 1;
var _loop = function (_a) {
  items.forEach(function (item) {
    return _a;
  });
};
for (var _a = 1; _a < 100; _a++) {
  _loop(_a);
}
console.log(a);
